# FilterAction

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**add_label_ids** | **list[str]** | List of labels to add to the message. | [optional] 
**forward** | **str** | Email address that the message should be forwarded to. | [optional] 
**remove_label_ids** | **list[str]** | List of labels to remove from the message. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

